summaryrefslogtreecommitdiffstats
path: root/kcontrol/konqhtml/jspolicies.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 04:10:07 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 04:10:07 +0000
commitfd3a982e26813f5bcc82c7e89ce6fa2ad44432bf (patch)
tree9eda848e56fcb862fdfdf479adeccd95b6fe387a /kcontrol/konqhtml/jspolicies.h
parent02f67d0e1355b79b1806746efb0f2f640e57f13d (diff)
downloadtdebase-fd3a982e26813f5bcc82c7e89ce6fa2ad44432bf.tar.gz
tdebase-fd3a982e26813f5bcc82c7e89ce6fa2ad44432bf.zip
Revert automated changes
Sorry guys, they are just not ready for prime time Work will continue as always git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdebase@1212480 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kcontrol/konqhtml/jspolicies.h')
-rw-r--r--kcontrol/konqhtml/jspolicies.h26
1 files changed, 13 insertions, 13 deletions
diff --git a/kcontrol/konqhtml/jspolicies.h b/kcontrol/konqhtml/jspolicies.h
index b2d08c11d..45352fbb9 100644
--- a/kcontrol/konqhtml/jspolicies.h
+++ b/kcontrol/konqhtml/jspolicies.h
@@ -50,16 +50,16 @@ public:
* Enumeration for all policies
*/
enum Policies { JavaScriptEnabled = 0, WindowOpen, WindowResize,
- WindowMove, WindowFocus, WindowtqStatus, NumPolicies };
+ WindowMove, WindowFocus, WindowStatus, NumPolicies };
#endif
/**
* constructor
* @param config configuration to initialize this instance from
- * @param group config group to use if this instance tqcontains the global
+ * @param group config group to use if this instance contains the global
* policies (global == true)
- * @param global true if this instance tqcontains the global policy settings,
- * false if this instance tqcontains policies specific for a domain.
+ * @param global true if this instance contains the global policy settings,
+ * false if this instance contains policies specific for a domain.
* @param domain name of the domain this instance is used to configure the
* policies for (case insensitive, ignored if global == true)
*/
@@ -141,19 +141,19 @@ public:
}
/**
* Returns whether the WindowtqStatus policy is inherited.
*/
- bool isWindowtqStatusPolicyInherited() const {
+ bool isWindowStatusPolicyInherited() const {
return window_status == INHERIT_POLICY;
}
/**
* Returns the current value of the WindowtqStatus policy.
*
* This will return an illegal value if isWindowtqStatusPolicyInherited is
* true.
*/
- KHTMLSettings::KJSWindowtqStatusPolicy windowtqStatusPolicy() const {
- return (KHTMLSettings::KJSWindowtqStatusPolicy)window_status;
+ KHTMLSettings::KJSWindowStatusPolicy windowStatusPolicy() const {
+ return (KHTMLSettings::KJSWindowStatusPolicy)window_status;
}
/**
@@ -178,7 +178,7 @@ private:
unsigned int window_move;
// one of KHTMLSettings::KJSWindowFocusPolicy or INHERIT_POLICY
unsigned int window_focus;
// one of KHTMLSettings::KJSWindowtqStatusPolicy or INHERIT_POLICY
unsigned int window_status;
friend class JSPoliciesFrame; // for changing policies
@@ -187,7 +187,7 @@ private:
/**
* @short Provides a framed widget with controls for the JavaScript policy settings.
*
- * This widget tqcontains controls for changing all JavaScript policies
+ * This widget contains controls for changing all JavaScript policies
* except the JavaScript enabled policy itself. The rationale behind this is
* that the enabled policy be separate from the rest in a prominent
* place.
@@ -253,7 +253,7 @@ private slots:
void setWindowResizePolicy(int id);
void setWindowMovePolicy(int id);
void setWindowFocusPolicy(int id);
- void setWindowtqStatusPolicy(int id);
+ void setWindowStatusPolicy(int id);
private:
@@ -141,19 +141,19 @@ public:
}
/**
- * Returns whether the WindowtqStatus policy is inherited.
+ * Returns whether the WindowStatus policy is inherited.
*/
@@ -141,19 +141,19 @@ public:
}
/**
- * Returns the current value of the WindowtqStatus policy.
+ * Returns the current value of the WindowStatus policy.
*
@@ -141,19 +141,19 @@ public:
*
- * This will return an illegal value if isWindowtqStatusPolicyInherited is
+ * This will return an illegal value if isWindowStatusPolicyInherited is
* true.
*/
@@ -178,7 +178,7 @@ private:
// one of KHTMLSettings::KJSWindowFocusPolicy or INHERIT_POLICY
unsigned int window_focus;
- // one of KHTMLSettings::KJSWindowtqStatusPolicy or INHERIT_POLICY
+ // one of KHTMLSettings::KJSWindowStatusPolicy or INHERIT_POLICY
unsigned int window_status;
friend class JSPoliciesFrame; // for changing policies